Translate Toolkit 3.8.5
***********************

*Released on 2 March 2023*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- JSON

  - Add support for go-i18n v2

Contributors
============

This release was made possible by the following people:

Nicolas Le Cam, Michal Čihař
